package com.ruoyi.frequency.banner.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.frequency.banner.entity.Banner;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 轮播图Mapper接口
 * 
 * @author liwenlong
 * @date 2023-07-20
 */
public interface BannerMapper  extends BaseMapper<Banner>
{
    /**
     * 查询轮播图
     * 
     * @param id 轮播图主键
     * @return 轮播图
     */
    Banner selectBannerById(Long id);

    /**
     * 查询轮播图列表
     * 
     * @param banner 轮播图
     * @return 轮播图集合
     */
    List<Banner> selectBannerList(Banner banner);

    /**
     * 新增轮播图
     * 
     * @param banner 轮播图
     * @return 结果
     */
    int insertBanner(Banner banner);

    /**
     * 修改轮播图
     * 
     * @param banner 轮播图
     * @return 结果
     */
    int updateBanner(Banner banner);

    /**
     * 删除轮播图
     * 
     * @param id 轮播图主键
     * @return 结果
     */
    int deleteBannerById(Long id);

    /**
     * 批量删除轮播图
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteBannerByIds(Long[] ids);

    String getMallGoodsDetail(@Param("goodsId") String goodsId);
}
